Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: content/renderer/media/webrtc_audio_renderer.h

Issue 139303016: Feed the render data to MediaStreamAudioProcessor and used AudioBus in render callback (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed the win bots. Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/webrtc_audio_renderer.h
diff --git a/content/renderer/media/webrtc_audio_renderer.h b/content/renderer/media/webrtc_audio_renderer.h
index 44894b52e8c67f1c9eaa28ed582fffb9fee00b34..b227de9a6bf5164c65842da2004af3d8b115a115 100644
--- a/content/renderer/media/webrtc_audio_renderer.h
+++ b/content/renderer/media/webrtc_audio_renderer.h
@@ -53,6 +53,10 @@ class CONTENT_EXPORT WebRtcAudioRenderer
// Used to DCHECK on the expected state.
bool IsStarted() const;
+ // Accessors to the sink audio parameters.
+ int channels() const { return number_of_channels_; }
+ int sample_rate() const { return sample_rate_; }
+
private:
// MediaStreamAudioRenderer implementation. This is private since we want
// callers to use proxy objects.
@@ -102,10 +106,6 @@ class CONTENT_EXPORT WebRtcAudioRenderer
// Audio data source from the browser process.
WebRtcAudioRendererSource* source_;
- // Buffers used for temporary storage during render callbacks.
- // Allocated during initialization.
- scoped_ptr<int16[]> buffer_;
-
// Protects access to |state_|, |source_| and |sink_|.
base::Lock lock_;
@@ -126,9 +126,11 @@ class CONTENT_EXPORT WebRtcAudioRenderer
// Delay due to the FIFO in milliseconds.
int fifo_delay_milliseconds_;
- // The preferred sample rate and buffer sizes provided via the ctor.
- const int sample_rate_;
- const int frames_per_buffer_;
+ // The sample rate, number of channels and buffer sizes used by the sink of
+ // the renderer.
tommi (sloooow) - chröme 2014/01/31 13:58:32 now that these are no longer const, can you docume
no longer working on chromium 2014/02/02 16:50:16 Added a comment to explain they are modified only
+ int sample_rate_;
+ int number_of_channels_;
+ int frames_per_buffer_;
DISALLOW_IMPLICIT_CONSTRUCTORS(WebRtcAudioRenderer);
};

Powered by Google App Engine
This is Rietveld 408576698